==> haskell-pandoc_3.1.3.orig.tar.gz: pandoc-3.1.3/test/command/7884.md <==
```
% pandoc -f html+epub_html_exts -t native
<body epub:type="bodymatter">
<section id="chapter-1" class="level1" data-number="1">
<h1 data-number="1">Chapter 1</h1>
<p>Here is a footnote.<a href="#fn1" class="footnote-ref" id="fnref1" epub:type="noteref">1</a></p>
<p>Here is a second footnote.<a href="#fn2" class="footnote-ref" id="fnref2" epub:type="noteref">2</a></p>
</section>
<section class="footnotes footnotes-end-of-document" epub:type="footnotes">
<hr />
<ol>
<li id="fn1" epub:type="footnote"><p>This is a test<a href="#fnref1" class="footnote-back" role="doc-backlink">↩︎</a></p></li>
<li id="fn2" epub:type="footnote"><p>This is another test<a href="#fnref2" class="footnote-back" role="doc-backlink">↩︎</a></p></li>
</ol>
</section>
</body>
^D
[ Div
    ( "chapter-1"
    , [ "section" , "level1" ]
    , [ ( "number" , "1" ) ]
    )
    [ Header
        1
        ( "chapter-1" , [] , [ ( "number" , "1" ) ] )
        [ Str "Chapter" , Space , Str "1" ]
    , Para
        [ Str "Here"
        , Space
        , Str "is"
        , Space
        , Str "a"
        , Space
        , Str "footnote."
        , Note
            [ Para
                [ Str "This"
                , Space
                , Str "is"
                , Space
                , Str "a"
                , Space
                , Str "test"
                ]
            ]
        ]
    , Para
        [ Str "Here"
        , Space
        , Str "is"
        , Space
        , Str "a"
        , Space
        , Str "second"
        , Space
        , Str "footnote."
        , Note
            [ Para
                [ Str "This"
                , Space
                , Str "is"
                , Space
                , Str "another"
                , Space
                , Str "test"
                ]
            ]
        ]
    ]
]

```

==> haskell-pandoc_3.1.11.1.orig.tar.gz: pandoc-3.1.11.1/test/command/7884.md <==
```
% pandoc -f html+epub_html_exts -t native
<body epub:type="bodymatter">
<section id="chapter-1" class="level1" data-number="1">
<h1 data-number="1">Chapter 1</h1>
<p>Here is a footnote.<a href="#fn1" class="footnote-ref" id="fnref1" epub:type="noteref">1</a></p>
<p>Here is a second footnote.<a href="#fn2" class="footnote-ref" id="fnref2" epub:type="noteref">2</a></p>
</section>
<section class="footnotes footnotes-end-of-document" epub:type="footnotes">
<hr />
<ol>
<li id="fn1" epub:type="footnote"><p>This is a test<a href="#fnref1" class="footnote-back" role="doc-backlink">↩︎</a></p></li>
<li id="fn2" epub:type="footnote"><p>This is another test<a href="#fnref2" class="footnote-back" role="doc-backlink">↩︎</a></p></li>
</ol>
</section>
</body>
^D
[ Div
    ( "chapter-1"
    , [ "section" , "level1" ]
    , [ ( "number" , "1" ) ]
    )
    [ Header
        1
        ( "" , [] , [ ( "number" , "1" ) ] )
        [ Str "Chapter" , Space , Str "1" ]
    , Para
        [ Str "Here"
        , Space
        , Str "is"
        , Space
        , Str "a"
        , Space
        , Str "footnote."
        , Note
            [ Para
                [ Str "This"
                , Space
                , Str "is"
                , Space
                , Str "a"
                , Space
                , Str "test"
                ]
            ]
        ]
    , Para
        [ Str "Here"
        , Space
        , Str "is"
        , Space
        , Str "a"
        , Space
        , Str "second"
        , Space
        , Str "footnote."
        , Note
            [ Para
                [ Str "This"
                , Space
                , Str "is"
                , Space
                , Str "another"
                , Space
                , Str "test"
                ]
            ]
        ]
    ]
]

```
